@@ -265,7 +265,7 @@ class Publish(object):
         if not snapshot:
             return []
 
-        source_snapshots = re.findall(r"'([\w\d-]+)'", snapshot['Description'])
+        source_snapshots = re.findall(r"'([\w\d\.-]+)'", snapshot['Description'])
         if not source_snapshots and fallback_self:
             source_snapshots = [snapshot['Name']]
 
@@ -288,20 +288,22 @@ class Publish(object):
                 continue
 
             # Look if merged snapshot doesn't already exist
-            remote_snapshot = self._find_snapshot(r'^%s%s-\d+' % (self.merge_prefix, component))
-            source_snapshots = self._get_source_snapshots(remote_snapshot)
+            remote_snapshot = self._find_snapshot(r'^%s%s-%s-\d+' % (self.merge_prefix, self.name.replace('./', '').replace('/', '-'), component))
+            if remote_snapshot:
+                source_snapshots = self._get_source_snapshots(remote_snapshot)
 
-            # Check if latest merged snapshot has same source snapshots like us
-            snapshots_want = list(snapshots)
-            snapshots_want.sort()
+                # Check if latest merged snapshot has same source snapshots like us
+                snapshots_want = list(snapshots)
+                snapshots_want.sort()
 
-            if snapshots_want == source_snapshots:
-                lg.info("Remote merge snapshot already exists: %s (%s)" % (remote_snapshot['Name'], source_snapshots))
-                self.publish_snapshots.append({
-                    'Component': component,
-                    'Name': remote_snapshot['Name']
-                })
-                continue
+                lg.debug("Comparing snapshots: snapshot_name=%s, snapshot_sources=%s, wanted_sources=%s" % (remote_snapshot['Name'], source_snapshots, snapshots_want))
+                if snapshots_want == source_snapshots:
+                    lg.info("Remote merge snapshot already exists: %s (%s)" % (remote_snapshot['Name'], source_snapshots))
+                    self.publish_snapshots.append({
+                        'Component': component,
+                        'Name': remote_snapshot['Name']
+                    })
+                    continue
 
             snapshot_name = '%s%s-%s-%s' % (self.merge_prefix, self.name.replace('./', '').replace('/', '-'), component, self.timestamp)
             lg.info("Creating merge snapshot %s for component %s of snapshots %s" % (snapshot_name, component, snapshots))
@@ -394,12 +396,11 @@ class Publish(object):
             to_publish.sort()
             published.sort()
 
-            if to_publish == published:
+            if recreate:
+                lg.info("Recreating publish %s" % self.name)
+                self.drop_publish()
+                self.create_publish(force_overwrite, publish_contents)
+            elif to_publish == published:
                 lg.info("Publish %s is up to date" % self.name)
             else:
-                if recreate:
-                    lg.info("Recreating publish %s" % self.name)
-                    self.drop_publish()
-                    self.create_publish(force_overwrite, publish_contents)
-                else:
-                    self.update_publish(force_overwrite, publish_contents)
+                self.update_publish(force_overwrite, publish_contents)
