@@ -29,7 +29,7 @@ def get_latest_snapshot(snapshots, name):
 
 
 def main():
-    parser = argparse.ArgumentParser("Aptly publisher")
+    parser = argparse.ArgumentParser("aptly-publisher")
 
     group_common = parser.add_argument_group("Common")
     parser.add_argument('action', help="Action to perform (publish, promote, cleanup)")
@@ -44,7 +44,7 @@ def main():
 
     group_publish = parser.add_argument_group("Action 'publish'")
     group_publish.add_argument('-c', '--config', default="/etc/aptly/publisher.yaml", help="Configuration YAML file")
-    group_publish.add_argument('--distributions', '--dists', nargs='+', help="Space-separated list of distribution to work with (including prefix), default all.")
+    group_publish.add_argument('--dists', nargs='+', help="Space-separated list of distribution to work with (including prefix), default all.")
 
     group_promote = parser.add_argument_group("Action 'promote'")
     group_promote.add_argument('--source', help="Source publish to take snapshots from")
